.. PyIBIS-AMI Developer Guide documentation master file, created by
   copying PyIBIS-AMI Sphinx files on Tue Jan 24 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

*PyIBIS-AMI* API User's Guide
==============================

Welcome to the *PyIBIS-AMI* API user's documentation!

Contents
--------

.. toctree::
   :maxdepth: 2

   install
   modules

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. mdinclude:: ../../README.md
